#[non_exhaustive]pub enum TypeAnnotation {
Absent,
Present(Type),
Malformed {
span: Span,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Absent
The source construct did not include a type annotation.
Present(Type)
The source construct included a type annotation that parsed cleanly.
Malformed
The source construct included a type annotation, but the parser could
not model it as a Type. Diagnostics carry the detailed message.
Implementations