#[non_exhaustive]pub enum AstSpanError {
InvalidSpan {
start: usize,
end: usize,
},
OverlappingSpans {
start: usize,
end: usize,
parent_start: usize,
parent_end: usize,
},
OverlappingTile {
start: usize,
end: usize,
previous_end: usize,
},
UncoveredBytes {
start: usize,
end: usize,
text: String,
},
UncoveredTail {
start: usize,
text: String,
},
ReconstructionMismatch {
reconstructed_len: usize,
source_len: usize,
},
IntervalStartAfterEnd {
start: usize,
end: usize,
},
IntervalExceedsSource {
start: usize,
end: usize,
source_len: usize,
},
IntervalNotUtf8Boundary {
start: usize,
end: usize,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidSpan
An AST span had start > end; both fields are byte offsets.
OverlappingSpans
Two AST spans overlapped without one containing the other.
Fields
OverlappingTile
A reconstruction tile overlapped bytes already emitted.
Fields
UncoveredBytes
A non-empty source byte interval was not covered by AST or trivia.
Fields
UncoveredTail
Source bytes after the final AST/trivia interval were not covered.
Fields
ReconstructionMismatch
Reconstructed source length differed from the original source length.
Fields
IntervalStartAfterEnd
A token/trivia interval had start > end; both fields are byte offsets.
IntervalExceedsSource
A token/trivia interval extended past source_len.
Fields
IntervalNotUtf8Boundary
A token/trivia interval boundary was not a UTF-8 boundary in source.