#[non_exhaustive]pub enum LexErrorKind {
UnexpectedCharacter(char),
UnterminatedBlockComment,
UnterminatedStringLiteral,
UnterminatedStringGap,
InvalidEscapeSequence(char),
StraySingleQuote,
CharacterLiteralWrongLength,
HexLiteralMissingDigits,
DecimalExponentMissingDigits,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnexpectedCharacter(char)
A character could not begin or continue any token.
UnterminatedBlockComment
A nested block comment reached EOF before -}.
UnterminatedStringLiteral
A string literal reached EOF or newline before its closing quote.
UnterminatedStringGap
A string gap was opened but not closed correctly.
InvalidEscapeSequence(char)
A string or character escape used an unsupported escape code.
StraySingleQuote
A single quote did not form a valid character literal.
CharacterLiteralWrongLength
A character literal decoded to zero or multiple Unicode scalar values.
HexLiteralMissingDigits
A 0x/0X literal prefix was not followed by a hexadecimal digit.
DecimalExponentMissingDigits
A decimal exponent marker was not followed by exponent digits.